#ifndef _INTERNAL_H
#define _INTERNAL_H 1

#include "config.h"
#include <stdint.h>
#include <libHX/defs.h>
#include <libHX/list.h>
#ifdef HAVE_VISIBILITY_HIDDEN
#	define EXPORT_SYMBOL __attribute__((visibility("default")))
#else
#	define EXPORT_SYMBOL
#endif

enum {
	NFXT_CHAIN_NAME_LEN = 48,
};

/**
 * @chains:		list/map of chains
 */
struct xtuser_table {
	struct HXmap *chains;
};

/**
 * @rule_list:		(ordered) list of rules (struct xtuser_rule)
 * @hook_num:		%NF_INET_* / %NF_ARP_* / %NF_BRIDGE_* / %XTNL_NO_HOOK.
 * @hook_prio:		priority value; no meaning when @hook_num==XTNL_NO_HOOK
 * @hook_nfproto:	%NFPROTO_*
 */
struct xtuser_chain {
	char name[NFXT_CHAIN_NAME_LEN];
	uint8_t hook_nfproto;
	uint8_t hook_num;
	int hook_priority;
	struct HXclist_head rule_list;
};

/**
 * @anchor:		anchor point for parent (struct xtuser_chain.rule_list)
 */
struct xtuser_rule {
	struct HXlist_head anchor;
	struct HXclist_head action_list;
};

struct xtuser_action {
	struct HXlist_head anchor;
	enum xtuser_action_type type;
	union {
		unsigned int verdict;
		struct {
			char *name;
			unsigned int revision;
			void *data;
			size_t dsize;
		} mt;
		char *jg_target;
	};
};

struct xtnetlink_identify {
	const char *name;
	unsigned int rev_min, rev_max;
};

extern int xtuser_rule_push_mt(struct xtuser_rule *, enum xtuser_action_type,
	const char *, unsigned int, const void *, size_t);
extern int xtuser_rule_push_jg(struct xtuser_rule *, enum xtuser_action_type,
	const char *);

#endif /* _INTERNAL_H */
