/*
 *	Minimal test program for the chain splice operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static int tf_chain_create(int argc, const char **argv, struct test_param *par)
{
	struct xtuser_chain *chain;
	int ret;

	if (argc < 2) {
		fprintf(stderr, "A chain name is required\n");
		return EXIT_FAILURE;
	}

	chain = xtuser_chain_create(NULL, argv[1]);
	if (chain == NULL) {
		fprintf(stderr, "xtuser_chain_create: %s\n",
		        xtuser_strerror(-errno));
		return EXIT_FAILURE;
	}

	ret = xtnetlink_chain_create(par->xth, chain);
	printf("Adding chain %s... (%d) %s\n",
	       argv[1], ret, xtuser_strerror(ret));
	if (ret != NFXTE_SUCCESS)
		return EXIT_FAILURE;

	ret = xtnetlink_chain_create(par->xth, chain);
	printf("should-fail: Adding chain %s again... (%d) %s\n",
	       argv[1], ret, xtuser_strerror(ret));
	if (ret == NFXTE_SUCCESS)
		return EXIT_FAILURE;

	xtuser_chain_free(chain);
	return EXIT_SUCCESS;
}

const struct test_program tp_chain_create = {
	.tfunc = tf_chain_create,
};
