/*
 *	Minimal test program for the chain splice operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <stdio.h>
#include <stdlib.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static int tf_chain_move(int argc, const char **argv, struct test_param *par)
{
	int ret;

	if (argc < 3) {
		fprintf(stderr, "Two names are required\n");
		return EXIT_FAILURE;
	}
	ret = xtnetlink_chain_move(par->xth, argv[1], argv[2]);
	printf("Renaming chain %s to %s... (%d) %s\n",
	       argv[1], argv[2], ret, xtuser_strerror(ret));
	if (ret != 0)
		return EXIT_FAILURE;

	ret = xtnetlink_chain_move(par->xth, argv[2], argv[1]);
	printf("Renaming chain %s back to %s again... (%d) %s\n",
	       argv[1], argv[2], ret, xtuser_strerror(ret));
	if (ret != 0)
		return EXIT_FAILURE;

	ret = xtnetlink_chain_move(par->xth, argv[1], argv[2]);
	printf("Renaming chain forward from %s to %s again... (%d) %s\n",
	       argv[1], argv[2], ret, xtuser_strerror(ret));
	if (ret != 0)
		return EXIT_FAILURE;

	return EXIT_SUCCESS;
}

const struct test_program tp_chain_move = {
	.tfunc = tf_chain_move,
};
