/*
 *	Minimal test program for chain promotion/demotion
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdlib.h>
#include <libHX/option.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static unsigned int prom_nfproto, prom_hooknum = 1;
static int prom_prio;

static int
tf_chain_promote(int argc, const char **argv, struct test_param *par)
{
	struct xtnetlink_promote_param p;
	int ret;

	if (argc < 2) {
		fprintf(stderr, "Need a chain name\n");
		return EXIT_FAILURE;
	}

	p.name = argv[1];
	p.priority = prom_prio;
	p.hooknum = prom_hooknum;
	p.nfproto = prom_nfproto;
	ret = xtnetlink_chain_promote(par->xth, &p);
	printf("Promoting chain %s to base chain... (%d) %s\n",
	       p.name, ret, xtuser_strerror(ret));
	return (ret == NFXTE_SUCCESS) ? EXIT_SUCCESS : EXIT_FAILURE;
}

static int tf_chain_demote(int argc, const char **argv, struct test_param *par)
{
	int ret;

	if (argc < 2) {
		fprintf(stderr, "Need a chain name\n");
		return EXIT_FAILURE;
	}

	ret = xtnetlink_chain_demote(par->xth, argv[1]);
	printf("Demoting chain %s... (%d) %s\n",
	       argv[1], ret, xtuser_strerror(ret));
	return (ret == NFXTE_SUCCESS) ? EXIT_SUCCESS : EXIT_FAILURE;
}

static const struct HXoption tf_chain_promote_options[] = {
	{.sh = 'f', .type = HXTYPE_UINT, .ptr = &prom_nfproto,
	 .help = "NFPROTO (2=IPV4, 3=ARP, 7=BRIDGE, 10=IPV6)"},
	{.sh = 'H', .ln = "hook", .type = HXTYPE_UINT, .ptr = &prom_hooknum,
	 .help = "Hook number (0..5=PRERO,INPUT,FORW,OUTPUT,POSTRO,BROUT)"},
	{.sh = 'p', .ln = "prio", .type = HXTYPE_INT, .ptr = &prom_prio,
	 .help = "Priority of the hook"},
	{.sh = 'x', .type = HXTYPE_NONE, .ptr = &t_hexdump,
	 .help = "Print hexdumps of all Netlink packet exchanges"},
	HXOPT_AUTOHELP,
	HXOPT_TABLEEND,
};

const struct test_program tp_chain_promote = {
	.options = tf_chain_promote_options,
	.tfunc   = tf_chain_promote,
};

const struct test_program tp_chain_demote = {
	.tfunc   = tf_chain_demote,
};
