/*
 *	Minimal test program for the chain splice operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <libHX/option.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static unsigned int splice_alength, splice_dlength, splice_offset;

static int tf_chain_splice(int argc, const char **argv, struct test_param *par)
{
	struct xtuser_chain *chain;
	const char *chain_name;
	unsigned int i;
	int ret;

	if (argc < 2) {
		fprintf(stderr, "Need a chain name\n");
		return EXIT_FAILURE;
	}

	chain_name = argv[1];
	chain = xtuser_chain_create(NULL, chain_name);
	ret = -errno;
	printf("Create local chain \"%s\"... (%d) %s\n",
	       chain_name, ret, xtuser_strerror(ret));
	if (chain == NULL)
		return ret;

	for (i = 0; i < splice_alength; ++i) {
		struct xtuser_rule *rule = xtuser_rule_new();

		ret = -errno;
		printf("Create local rule %u/%u... (%d) %s\n",
		       i, splice_alength, ret, xtuser_strerror(ret));
		if (rule == NULL) {
			xtuser_chain_free(chain);
			return ret;
		}

		ret = xtuser_chain_push(chain, rule);
		printf("Adding rule %u to local chain... (%d) %s\n",
		       i, ret, xtuser_strerror(ret));
		if (ret < 0) {
			xtuser_chain_free(chain);
			return ret;
		}
	}

	printf("Created %u rules\n", splice_alength);
	ret = xtnetlink_chain_splice(par->xth, chain,
		splice_offset, splice_dlength);
	printf("Splicing [offset=%u,delete=%u,insert=%u] "
	       "into chain %s... (%d) %s\n",
	       splice_offset, splice_dlength, splice_alength, chain_name,
	       ret, xtuser_strerror(ret));
	xtuser_chain_free(chain);
	return ret;
}

static const struct HXoption tf_chain_splice_options[] = {
	{.sh = 'a', .ln = "alen", .type = HXTYPE_UINT,
	 .ptr = &splice_alength, .help = "Number of rules to add"},
	{.sh = 'd', .ln = "dlen", .type = HXTYPE_UINT,
	 .ptr = &splice_dlength, .help = "Number of rules to delete"},
	{.sh = 'o', .ln = "offset", .type = HXTYPE_UINT,
	 .ptr = &splice_offset, .help = "Start from given rule index"},
	{.sh = 'x', .type = HXTYPE_NONE, .ptr = &t_hexdump,
	 .help = "Print hexdumps of all Netlink packet exchanges"},
	HXOPT_AUTOHELP,
	HXOPT_TABLEEND,
};

const struct test_program tp_chain_splice = {
	.options = tf_chain_splice_options,
	.tfunc   = tf_chain_splice,
};
