/*
 *	Minimal test program for the IDENTIFY operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <libHX/option.h>
#include <libnetfilter_xtables/props.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static int tf_identify(int argc, const char **argv, struct test_param *par)
{
	struct xtnetlink_identify *id = NULL;
	unsigned int rev_min, rev_max;
	const char *imp;
	int ret;

	ret = xtnetlink_identify(par->xth, &id);
	if (ret != 0) {
		fprintf(stderr, "ERROR: xtnetlink_identify: %s\n",
		        xtuser_strerror(errno));
		return EXIT_FAILURE;
	}

	imp = xtnetlink_identprop_impname(id);
	printf("Implementation: %s\n",
	       (imp == NULL) ? "(not disclosed)" : imp);
	rev_min = xtnetlink_identprop_revmin(id);
	rev_max = xtnetlink_identprop_revmax(id);
	if (rev_min == rev_max)
		printf("Supported revision: %u\n", rev_max);
	else
		printf("Supported revisions: %u─%u\n", rev_min, rev_max);
	xtnetlink_ident_free(id);
	return EXIT_SUCCESS;
}

const struct test_program tp_identify = {
	.tfunc   = tf_identify,
};
