/*
 *	Minimal test program for the chain splice operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <libHX/option.h>
#include <libnetfilter_xtables/xtuser.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/props.h>
#include "t-common.h"

static int tf_table_dump(int argc, const char **argv, struct test_param *par)
{
	struct xtuser_table_iter *iter;
	struct xtuser_table *table;
	struct xtuser_chain *chain;
	int ret;

	table = xtnetlink_table_dump(par->xth);
	printf("Retrieving table... (%d) %s\n", -errno,
	       xtuser_strerror(-errno));
	if (table == NULL)
		return EXIT_FAILURE;

	iter = xtuser_table_travinit(table);
	while ((chain = xtuser_table_traverse(iter)) != NULL) {
		ret = tf_chain_print(chain);
		if (ret != EXIT_SUCCESS)
			break;
	}
	xtuser_table_travfree(iter);
	xtuser_table_free(table);
	return EXIT_SUCCESS;
}

const struct test_program tp_table_dump = {
	.tfunc = tf_table_dump,
};
