/*
 *	Minimal test program for the chain splice operation
 *	written by Jan Engelhardt, 2012
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the WTF Public License version 2 or
 *	(at your option) any later version.
 */
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <libHX/option.h>
#include <libnetfilter_xtables/xtnetlink.h>
#include <libnetfilter_xtables/xtuser.h>
#include "t-common.h"

static unsigned int flush_loops = 1;

static int tf_table_flush(int argc, const char **argv, struct test_param *par)
{
	struct xtuser_table *table;
	int ret;

	table = xtuser_table_new();
	if (table == NULL) {
		fprintf(stderr, "xtuser_table_new: %s\n",
		        xtuser_strerror(-errno));
		return EXIT_FAILURE;
	}
	while (flush_loops-- > 0) {
		ret = xtnetlink_table_replace(par->xth, table);
		printf("(%u) Flushing table... (%d left) %s\n",
		       flush_loops, ret, xtuser_strerror(ret));
		if (ret != NFXTE_SUCCESS)
			return EXIT_FAILURE;
	}
	return EXIT_SUCCESS;
}

static const struct HXoption tf_table_flush_options[] = {
	{.sh = 'l', .ln = "loops", .type = HXTYPE_UINT, .ptr = &flush_loops,
	 .help = "Do this many flushs after one another"},
	{.sh = 'x', .type = HXTYPE_NONE, .ptr = &t_hexdump,
	 .help = "Print hexdumps of all Netlink packet exchanges"},
	HXOPT_AUTOHELP,
	HXOPT_TABLEEND,
};

const struct test_program tp_table_flush = {
	.options = tf_table_flush_options,
	.tfunc   = tf_table_flush,
};
